==> dbus-switchboard_1.2.15-1fremantle1.tar.gz: dbus-switchboard-1.2.15/src/usr/bin/dswitch-init.sh <==
#!/bin/sh

# qole says: This hackish script really needs to go away. 
#            It is embarrassing.

cp /usr/share/applications/defaults.list /usr/share/applications/defaults.list~

echo "video/quicktime=hildon-mediaplayer.desktop" >> /usr/share/applications/defaults.list
echo "video-quicktime=hildon-mediaplayer.desktop:X-Osso-URI-Action-Open" >> /usr/share/applications/uri-action-defaults.list

echo "" >> /usr/share/applications/defaults.list
echo "# Catch-all on N900" >> /usr/share/applications/defaults.list
echo "unknown/unknown=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list

echo "" >> /usr/share/applications/defaults.list
echo "# DBus-Switchboard default associations" >> /usr/share/applications/defaults.list
echo "application/x-bittorrent=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "audio/mid=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "audio/dbs-mid=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "application/dbs-torrent=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "application/octet-stream=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "application/x-cbr=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-ascx=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-aspx=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-c=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-cpp=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-csharp=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-csv=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-doc=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-h=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-gpx=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-pdb=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-ppt=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-python=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-rtf=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-sh=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-tgz=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-xls=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-vb=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "application/dbs-jar=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list

==> dbus-switchboard_1.2.16-1fremantle1.tar.gz: dbus-switchboard-1.2.16/src/usr/bin/dswitch-init.sh <==
#!/bin/sh

# qole says: This hackish script really needs to go away. 
#            It is embarrassing.

cp /usr/share/applications/defaults.list /usr/share/applications/defaults.list~

echo "video/quicktime=hildon-mediaplayer.desktop" >> /usr/share/applications/defaults.list
echo "video-quicktime=hildon-mediaplayer.desktop:X-Osso-URI-Action-Open" >> /usr/share/applications/uri-action-defaults.list

echo "application/postscript=dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "application-postscript=dbus-switchboard.desktop" >> /usr/share/applications/uri-action-defaults.list


echo "" >> /usr/share/applications/defaults.list
echo "# Catch-all on N900" >> /usr/share/applications/defaults.list
echo "unknown/unknown=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list

echo "" >> /usr/share/applications/defaults.list
echo "# DBus-Switchboard default associations" >> /usr/share/applications/defaults.list
echo "application/x-bittorrent=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "audio/mid=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "audio/dbs-mid=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "application/dbs-torrent=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "application/octet-stream=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "application/x-cbr=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-ascx=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-aspx=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-c=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-cpp=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-csharp=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-csv=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-doc=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-h=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-gpx=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-pdb=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-ppt=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-python=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-rtf=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-sh=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-tgz=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-xls=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "text/dbs-vb=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
echo "application/dbs-jar=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
